@@ -591,6 +591,12 @@ execute_command(const VC_RECORD * vc, gchar ** std_out, gchar ** std_err, const
 	return ret;
 }
 
+static gint
+get_command_exit_status(gint exit_code)
+{
+	return (SPAWN_WIFEXITED(exit_code) ? SPAWN_WEXITSTATUS(exit_code) : exit_code);
+}
+
 /* Callback if menu item for a single file was activated */
 static void
 vcdiff_file_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer gdata)
@@ -1800,8 +1806,28 @@ vccommit_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer
 		gtk_tree_model_foreach(model, get_commit_files_foreach, &selected_files);
 		if (!EMPTY(message) && selected_files)
 		{
-			execute_command(vc, NULL, NULL, dir, VC_COMMAND_COMMIT, selected_files,
+			gchar *err_output = NULL;
+			gint exit_code;
+
+			exit_code = execute_command(vc, NULL, &err_output, dir, VC_COMMAND_COMMIT, selected_files,
 					message);
+
+			if (err_output)
+			{
+				gint status = get_command_exit_status(exit_code);
+
+				/* - log the commit error (may be a very long message) into the Message Window
+				   - overwrite the status bar with a more concise message
+				*/
+				g_warning("geanyvc: vccommit_activated: Commit failed (status:%d).", status);
+				ui_set_statusbar(TRUE, _("Commit failed (status: %d, error: %s)."), status, err_output);
+				ui_set_statusbar(FALSE, _("Commit failed; see status in the Message window."));
+				g_free(err_output);
+			}
+			else
+			{
+				ui_set_statusbar(FALSE, _("Changes committed."));
+			}
 			free_text_list(selected_files);
 		}
 		g_free(message);
@@ -2165,7 +2191,7 @@ plugin_configure(GtkDialog * dialog)
 	gtk_box_pack_start(GTK_BOX(vbox), widgets.cb_editor_menu_entries, TRUE, FALSE, 2);
 
 	widgets.cb_attach_to_menubar = gtk_check_button_new_with_label(_("Attach menu to menubar"));
-	gtk_widget_set_tooltip_text(widgets.cb_editor_menu_entries,
+	gtk_widget_set_tooltip_text(widgets.cb_attach_to_menubar,
 				 _("Whether menu for this plugin are getting placed either "
 				   "inside tools menu or directly inside Geany's menubar. "
 				   "Will take in account after next start of GeanyVC"));
@@ -2523,7 +2549,7 @@ add_menuitems_to_editor_menu(void)
 	/* Add commit item to editor menu */
 	if (set_editor_menu_entries == TRUE && editor_menu_commit == NULL)
 	{
-		editor_menu_commit = gtk_menu_item_new_with_mnemonic(_("VC _Commit"));
+		editor_menu_commit = gtk_menu_item_new_with_mnemonic(_("VC _Commit..."));
 		gtk_container_add(GTK_CONTAINER(geany->main_widgets->editor_menu), editor_menu_commit);
 		g_signal_connect(editor_menu_commit, "activate",
 			G_CALLBACK(vccommit_activated), NULL);
@@ -2657,7 +2683,7 @@ plugin_init(G_GNUC_UNUSED GeanyData * data)
 	g_signal_connect(menu_vc_update, "activate", G_CALLBACK(vcupdate_activated), NULL);
 
 	/* Commit all changes */
-	menu_vc_commit = gtk_menu_item_new_with_mnemonic(_("_Commit"));
+	menu_vc_commit = gtk_menu_item_new_with_mnemonic(_("_Commit..."));
 	gtk_container_add(GTK_CONTAINER(menu_vc_menu), menu_vc_commit);
 	gtk_widget_set_tooltip_text(menu_vc_commit, _("Commit changes."));
 
